@@ -1,7 +1,7 @@
 package Calendar::Dates::FRM;
 
 our $DATE = '2019-02-14'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -55,7 +55,178 @@ Calendar::Dates::FRM - FRM exam calendar
 
 =head1 VERSION
 
-This document describes version 0.002 of Calendar::Dates::FRM (from Perl distribution Calendar-Dates-FRM), released on 2019-02-14.
+This document describes version 0.003 of Calendar::Dates::FRM (from Perl distribution Calendar-Dates-FRM), released on 2019-02-14.
+
+=head1 SYNOPSIS
+
+=head2 Using from Perl
+
+ use Calendar::Dates::FRM;
+ my $min_year = Calendar::Dates::FRM->get_min_year; # => 2018
+ my $max_year = Calendar::Dates::FRM->get_max_year; # => 2020
+ my $entries  = Calendar::Dates::FRM->get_entries(2019);
+
+C<$entries> result:
+
+ [
+   {
+     date    => "2019-01-03",
+     day     => 3,
+     month   => 1,
+     summary => "Exam results sent via email",
+     tags    => ["nov2018exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-01-31",
+     day     => 31,
+     month   => 1,
+     summary => "Early registration closed",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-02-01",
+     day     => 1,
+     month   => 2,
+     summary => "Standard registration opened",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-02-28",
+     day     => 28,
+     month   => 2,
+     summary => "Standard registration closed",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-03-01",
+     day     => 1,
+     month   => 3,
+     summary => "Late registration opened",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-04-15",
+     day     => 15,
+     month   => 4,
+     summary => "Late registration closed",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-04-15",
+     day     => 15,
+     month   => 4,
+     summary => "Defer deadline",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-05-01",
+     day     => 1,
+     month   => 5,
+     summary => "Admission tickets released",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-05-18",
+     day     => 18,
+     month   => 5,
+     summary => "Exam day",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-06-28",
+     day     => 28,
+     month   => 6,
+     summary => "Exam results sent via email",
+     tags    => ["may2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-05-01",
+     day     => 1,
+     month   => 5,
+     summary => "Early registration opened",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-07-31",
+     day     => 31,
+     month   => 7,
+     summary => "Early registration closed",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-08-01",
+     day     => 1,
+     month   => 8,
+     summary => "Standard registration opened",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-08-31",
+     day     => 31,
+     month   => 8,
+     summary => "Standard registration closed",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-09-01",
+     day     => 1,
+     month   => 9,
+     summary => "Late registration opened",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-10-15",
+     day     => 15,
+     month   => 10,
+     summary => "Late registration closed",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-10-15",
+     day     => 15,
+     month   => 10,
+     summary => "Defer deadline",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-11-01",
+     day     => 1,
+     month   => 11,
+     summary => "Admission tickets released",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-11-16",
+     day     => 16,
+     month   => 11,
+     summary => "Exam day",
+     tags    => ["nov2019exam"],
+     year    => 2019,
+   },
+ ]
+
+=head2 Using from CLI (requires L<list-calendar-dates> and L<calx>)
+
+ % list-calendar-dates -l -m FRM
+ % calx -c FRM
 
 =head1 DESCRIPTION
 
